AppColors class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- darkBackground → const Color
- darkBorder → const Color
- darkBubble → const Color
- darkSurface → const Color
- darkText → const Color
- lightBackground → const Color
- lightBorder → const Color
- lightBubble → const Color
- lightSurface → const Color
- lightText → const Color
- online → const Color
- primary → const Color
- primaryDark → const Color
- primaryGradient → const LinearGradient